@@ -31,6 +31,11 @@
 #include <vector>
 #include <limits>
 #include <iostream>
+#ifdef HAVE_CXX11
+#include <cstdint>
+#else
+#include <stdint.h>
+#endif
 
 namespace vcg {
 
@@ -42,7 +47,7 @@ namespace vcg {
         inline ConstDataWrapper()
             : mpData(0), mStride(0), mSize(0)
         {}
-        inline ConstDataWrapper(const DataType* pData, int size, int stride = sizeof(DataType))
+        inline ConstDataWrapper(const DataType* pData, int size, int64_t stride = sizeof(DataType))
             : mpData(reinterpret_cast<const unsigned char*>(pData)), mStride(stride), mSize(size)
         {}
         inline const DataType& operator[] (int i) const
@@ -52,7 +57,7 @@ namespace vcg {
         inline size_t size() const { return mSize; }
     protected:
         const unsigned char* mpData;
-        int mStride;
+        int64_t mStride;
         size_t mSize;
     };
 
@@ -139,7 +144,7 @@ namespace vcg {
         // and returns the index of the first element of the second subset
         unsigned int split(int start, int end, unsigned int dim, float splitValue);
 
-        void createTree(unsigned int nodeId, unsigned int start, unsigned int end, unsigned int level, unsigned int targetCellsize, unsigned int targetMaxDepth);
+        int createTree(unsigned int nodeId, unsigned int start, unsigned int end, unsigned int level, unsigned int targetCellsize, unsigned int targetMaxDepth);
 
     protected:
 
@@ -156,7 +161,7 @@ namespace vcg {
         // compute the AABB of the input
         mPoints[0] = points[0];
         mAABB.Set(mPoints[0]);
-        for (unsigned int i=1 ; i<mPoints.size() ; ++i)
+		for (unsigned int i=1 ; i<mPoints.size() ; ++i)
         {
             mPoints[i] = points[i];
             mIndices[i] = i;
@@ -164,11 +169,10 @@ namespace vcg {
         }
 
         mNodes.reserve(4*mPoints.size()/nofPointsPerCell);
-
-        //first node inserted (no leaf). The others are made by the createTree function (recursively)
+		//first node inserted (no leaf). The others are made by the createTree function (recursively)
         mNodes.resize(1);
         mNodes.back().NodeU.mynode.leaf = 0;
-        createTree(0, 0, mPoints.size(), 1, nofPointsPerCell, maxDepth);
+        int numLevel = createTree(0, 0, mPoints.size(), 1, nofPointsPerCell, maxDepth);
     }
 
     template<typename Scalar>
@@ -438,7 +442,7 @@ namespace vcg {
     *  is more expensive than the gain it provides and the memory consumption is x4 higher !
     */
     template<typename Scalar>
-    void KdTree<Scalar>::createTree(unsigned int nodeId, unsigned int start, unsigned int end, unsigned int level, unsigned int targetCellSize, unsigned int targetMaxDepth)
+    int KdTree<Scalar>::createTree(unsigned int nodeId, unsigned int start, unsigned int end, unsigned int level, unsigned int targetCellSize, unsigned int targetMaxDepth)
     {
         //select the first node
         Node& node = mNodes[nodeId];
@@ -459,31 +463,33 @@ namespace vcg {
         else
             dim = diag.Y() > diag.Z() ? 1 : 2;
 
-	node.NodeU.mynode.dim = dim;
+        node.NodeU.mynode.dim = dim;
         //we divide the bounding box in 2 partitions, considering the average of the "dim" dimension
-	node.NodeU.mynode.splitValue = Scalar(0.5*(aabb.max[dim] + aabb.min[dim]));
-
+        node.NodeU.mynode.splitValue = Scalar(0.5*(aabb.max[dim] + aabb.min[dim]));
+	
         //midId is the index of the first element in the second partition
-        unsigned int midId = split(start, end, dim, node.NodeU.mynode.splitValue);
+        unsigned int midId = split(start, end, dim,node.NodeU.mynode.splitValue);
 
 
         node.NodeU.mynode.firstChildId = mNodes.size();
         mNodes.resize(mNodes.size()+2);
+		int leftLevel, rightLevel;
 
         {
             // left child
-            unsigned int childId = mNodes[nodeId].NodeU.mynode.firstChildId;
+            unsigned int childId = mNodes[nodeId].NodeU.mynode.firstChildId;;
             Node& child = mNodes[childId];
             if (midId - start <= targetCellSize || level>=targetMaxDepth)
             {
                 child.NodeU.mynode.leaf = 1;
-                child.NodeU.myleaf.start = start;
+		child.NodeU.myleaf.start = start;
                 child.NodeU.myleaf.size = midId - start;
+				leftLevel = level;
             }
             else
             {
                 child.NodeU.mynode.leaf = 0;
-                createTree(childId, start, midId, level+1, targetCellSize, targetMaxDepth);
+                leftLevel = createTree(childId, start, midId, level+1, targetCellSize, targetMaxDepth);
             }
         }
 
@@ -496,13 +502,17 @@ namespace vcg {
                 child.NodeU.mynode.leaf = 1;
                 child.NodeU.myleaf.start = midId;
                 child.NodeU.myleaf.size = end - midId;
+				rightLevel = level;
             }
             else
             {
                 child.NodeU.mynode.leaf = 0;
-                createTree(childId, midId, end, level+1, targetCellSize, targetMaxDepth);
+                rightLevel = createTree(childId, midId, end, level+1, targetCellSize, targetMaxDepth);
             }
         }
+		if (leftLevel > rightLevel)
+			return leftLevel;
+		return rightLevel;
     }
 }
 
